//! Handles building the database, and exposes data structures for the database and ways to interact with them
use super::*;
use std::{
    collections::{
	HashMap,
	HashSet,
    },
    path::{
	PathBuf,
	Path,
    },
};
use chrono::{
    DateTime,
    Utc,
};

#[derive(Debug, PartialEq, Eq)]
pub struct Database
{
    /// Key here is the actual location in /tmp/videl of the database and versioned files
    database: HashMap<PathBuf,Entry>,
}

#[derive(Debug, PartialEq, Eq)]
pub struct Entry
{
    /// Versions are a hashset because we don't need to version files that are /entirely/ identical. (i.e. same timestamp and hash)
    versions: HashSet<Version>,
}

#[derive(Debug, PartialEq, Eq, Hash)]
pub struct Version
{
    date: DateTime<Utc>,
    hash: hash::Sha256Sum,
    size: usize,
}

impl Version
{
    /// Gets the lowermost name of the path for this specific version
    pub fn get_pathname(&self) -> String
    {
	format!("{}", self.date.timestamp_nanos())
    }
}
